#ifndef SvgRenderer_h
#define SvgRenderer_h

// $Id: SvgRenderer.h,v 1.7 2010/03/25 16:33:11 hpereira Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

/*!
\file SvgRenderer.h
\brief construct pixmap of given size using Svg renderer
\author Hugo Pereira
\version $Revision: 1.7 $
\date $Date: 2010/03/25 16:33:11 $
*/

#include <QSvgRenderer>
#include <QPaintDevice>

#include "Counter.h"

//! construct pixmap of given size using Svg renderer
namespace SVG
{
    class SvgRenderer: public QSvgRenderer
    {

        public:

        //! constructor
        SvgRenderer( void );

        //! destructor
        virtual ~SvgRenderer( void )
        {}

        //! render
        void render( QPaintDevice&, double offset = 0, const QString& id = QString() );

        //! validity
        virtual bool isValid( void ) const;

        //! configuration
        bool updateConfiguration( void );

        protected:

        class Margins
        {
            public:

            //! constructor
            Margins( void ):
                left(0),
                right(0),
                top(0),
                bottom(0)
            {}

            double left;
            double right;
            double top;
            double bottom;
        };

        //! load margins
        Margins _margins( void ) const;

        //! true if svg has overlay
        virtual bool _hasOverlay( void ) const;

        //! true if svg has all elements matching prefix
        virtual bool _hasPrefix( QString prefix = "" ) const;

        //! render prefix to image
        virtual void _render( QImage& target, double offset = 0, QString prefix = "" );

        private:

        bool drawOverlay_;


    };

};
#endif
