#ifndef _PixmapList_h_
#define _PixmapList_h_

// $Id: PixmapList.h,v 1.11 2009/09/09 02:29:47 hpereira Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

/*!
  \file    PixmapList.h
  \brief   handles collection of pixmaps needed to draw a single button
  \author  Hugo Pereira
  \version $Revision: 1.11 $
  \date    $Date: 2009/09/09 02:29:47 $
*/

#include <cassert>
#include <QPixmap>
#include <QHash>

#include "Counter.h"
#include "Debug.h"
#include "TaskAttributes.h"
#include "TaskBarAttributes.h"

//! handles collection of pixmaps needed to draw a single button
class PixmapList: public Counter
{

  public:

  //! constructor
  PixmapList( void );

  //! destructor
  ~PixmapList( void );

  //! constructor
  void setAttributes( const TaskBarAttributes&, const TaskAttributes& );

  //! get pixmap matching given size and highlight
  /*!
  note: the method is set to 'const' although technically it has the ability
  to modify the internal cache.
  */
  const QPixmap& get( const unsigned int& size_index, const unsigned int& highlight_index ) const;

  //! max size index
  const unsigned int& maxSizeIndex( void ) const
  { return max_size_index_; }

  //! max highlight index
  const unsigned int& maxHighlightIndex( void ) const
  { return max_highlight_index_; }

  private:

  //! returns unique index from size and highlight
  unsigned int _index( const unsigned int& size_index, const unsigned int& highlight_index ) const;

  //! taskbar attributes
  TaskBarAttributes bar_attributes_;

  //! task attributes
  TaskAttributes attributes_;

  //! max size
  unsigned int max_size_;

  //! min size
  unsigned int min_size_;

  //! size increment
  unsigned int size_increment_;

  //! max size index
  unsigned int max_size_index_;

  //! max highlight index
  unsigned int max_highlight_index_;

  //! full intensity
  double full_intensity_;

  //! pixmap list
  typedef std::vector<QPixmap> List;

  //! normal pixmap
  List pixmaps_;

};

#endif
