#ifndef _TaskBarMinimum_h_
#define _TaskBarMinimum_h_

// $Id: TaskBarMinimum.h,v 1.32 2009/09/09 02:29:48 hpereira Exp $


/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

/*!
  \file    TaskBarMinimum.h
  \brief   transparent frame to display TaskButton(s)
  \author  Hugo Pereira
  \version $Revision: 1.32 $
  \date    $Date: 2009/09/09 02:29:48 $
*/

#include "TaskBarBase.h"

//! Taskbar main widget
class TaskBarMinimum: public TaskBarBase
{

  //! qt meta object
  Q_OBJECT

  public:

  //! constructor
  TaskBarMinimum( QWidget *parent=0 );

  protected slots:

  //! root pixmap
  virtual void _updateRootPixmap( void );

  //! background background
  virtual void _updateBackgroundPixmap( void );

  protected:

  //!@name event handlers
  //@{

  //! resize event method
  virtual void resizeEvent( QResizeEvent* );

  //@}

  //! resize the taskbar so that is is able to contain all buttons
  virtual void _resize( void );

  //! place buttons in the taskbar
  /*!  by default, first button starts at (0,0) */
  virtual void _placeButtons( void );

  //! adds offset to the buttons
  virtual void _addOffsets( void );

  //! draw buttons
  /*!
    if force is true, only buttons which are zooming are drawn
    returns true if at least one if zooming
  */
  virtual bool _drawButtons( QPaintDevice&, QRect );

  //! draw visible rect
  virtual void _drawVisibleRect( QPainter& );

  //! update minimum size
  virtual void _updateMinimumSize( void );

  //! update minimum rect
  virtual void _updateMinimumRectPosition( void );

  //! minimum size
  virtual QSize _minimumSize() const
  { return minimum_rect_.size(); }

  //! minimum size
  virtual void _setMinimumSize( const QSize& size )
  { minimum_rect_.setSize( size ); }

  //! minimum size
  virtual QRect _minimumRect() const
  { return minimum_rect_; }

  //! minimum size
  virtual void _setMinimumRect( const QRect& rect )
  { minimum_rect_ = rect; }

  //! update maximum size
  virtual void _updateMaximumSize( void );

  //! maximum size
  virtual const QSize& _maximumSize() const
  { return maximum_size_; }

  //! maximum size
  virtual void _setMaximumSize( const QSize& size )
  { maximum_size_ = size; }

  //! update visible rect
  virtual void _updateVisibleRect( void );

  //! update geometry (mask) for enter/leave event
  virtual bool _updateGeometry( Action action );

  //! visible rect
  virtual const QRect& _visibleRect( void ) const
  { return visible_rect_; }

  //! visible rect
  virtual QRect& _visibleRect( void )
  { return visible_rect_; }

  //! visible rect
  virtual void _setVisibleRect( const QRect& rect )
  { visible_rect_ = rect; }

  //! root pixmap
  virtual QPixmap _rootPixmap( void ) const
  { return root_pixmap_; }

  //! root pixmap
  virtual QPixmap& _rootPixmap( void )
  { return root_pixmap_; }

  //! root pixmap
  virtual void _setRootPixmap( QPixmap pixmap )
  { root_pixmap_ = pixmap; }

  //! root pixmap needs update
  virtual const bool& _rootPixmapChanged( void ) const
  { return root_pixmap_changed_; }

  //! root pixmap needs update
  virtual void _setRootPixmapChanged( const bool& value )
  { root_pixmap_changed_ = value; }

  private:

  //! preload svg
  void _preloadSvg( void ) const;

  //! taskbar minimum size
  QRect minimum_rect_;

  //! taskbar maximum size
  QSize maximum_size_;

  //! taskbar visible rect
  /*! this represents the rectangle that is shaded and on top of which the buttons are drawn */
  QRect visible_rect_;

  //! root pixmap
  QPixmap root_pixmap_;

  //! root pixmap needs update
  bool root_pixmap_changed_;

};

#endif
