#ifndef _TaskBarOsx_h_
#define _TaskBarOsx_h_

// $Id: TaskBarOsx.h,v 1.18 2009/09/09 02:29:48 hpereira Exp $


/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

/*!
  \file    TaskBarOsx.h
  \brief   transparent frame to display TaskButton(s)
  \author  Hugo Pereira
  \version $Revision: 1.18 $
  \date    $Date: 2009/09/09 02:29:48 $
*/

#include <QSize>
#include <map>

#include "TaskBarBase.h"

//! Taskbar main widget
class TaskBarOsx: public TaskBarBase
{

  public:

  //! constructor
  TaskBarOsx( QWidget *parent=0 );

  protected slots:

  //! root pixmap
  virtual void _updateRootPixmap( void );

  //! background background
  virtual void _updateBackgroundPixmap( void );

  protected:

  //!@name event handlers
  //@{

  //! resize event method
  virtual void resizeEvent( QResizeEvent* );

  //! pointer leaves window
  virtual void enterEvent( QEvent *event );

  //! pointer leaves window
  virtual void leaveEvent( QEvent *event );

  //! mouse move event
  virtual void mouseMoveEvent( QMouseEvent *event );

  //@}

  //! resize the taskbar so that is is able to contain all buttons
  virtual void _resize( void );

  //! place buttons in the taskbar
  void _placeButtons( void );

  //! adds offset to the buttons
  virtual void _addOffsets( void );

  //! draw buttons
  /*!
    if force is true, only buttons which are zooming are drawn
    returns true if at least one if zooming
  */
  virtual bool _drawButtons( QPaintDevice&, QRect );

  //! draw visible rect
  virtual void _drawVisibleRect( QPainter& );

  //! update minimum size
  virtual void _updateMinimumSize( void );

  //! update minimum rect
  virtual void _updateMinimumRectPosition( void );

  //! minimum size
  virtual QSize _minimumSize() const
  { return minimum_rect_.size(); }

  //! minimum size
  virtual void _setMinimumSize( const QSize& size )
  { minimum_rect_.setSize( size ); }

  //! minimum size
  virtual QRect _minimumRect() const
  { return minimum_rect_; }

  //! minimum size
  virtual void _setMinimumRect( const QRect& rect )
  { minimum_rect_ = rect; }

  //! update maximum size
  void _updateMaximumSize( void );

  //! maximum size
  virtual const QSize& _maximumSize() const
  { return maximum_sizes_.back(); }

  //! maximum size
  virtual const QSize& _maximumSize( const int& index ) const
  {
    assert( index < (int) maximum_sizes_.size() );
    return maximum_sizes_[index];
  }

  //! maximum size
  virtual void _setMaximumSize( const QSize& size )
  { assert(0); }

  //! mid position
  virtual void _clearMaximumSizes( void )
  { maximum_sizes_.clear(); }

  //! maximum size
  virtual void _addMaximumSize( const QSize& size )
  { maximum_sizes_.push_back( size ); }

  //! mid position, used to switch from one side of the bar to the other
  virtual const QPoint& _midPosition( const int& index ) const
  {
    assert( index < (int) maximum_sizes_.size() );
    return mid_positions_[index];
  }

  //! mid position
  virtual void _clearMidPositions( void )
  { mid_positions_.clear(); }

  //! mid position, used to switch from one side of the bar to the other
  virtual void _addMidPosition( const QPoint& value )
  { mid_positions_.push_back( value ); }

  //! mouse offset to get the proper size when one is on the "wrong" side of the bar
  virtual const QPoint& _mouseOffset() const
  { return mouse_offset_; }

  //! mouse offset to get the proper size when one is on the "wrong" side of the bar
  virtual void _setMouseOffset( const QPoint& value )
  { mouse_offset_ = value; }

  //! update visible rect
  virtual void _updateVisibleRect( void );

  //! update geometry (mask) for enter/leave event
  virtual bool _updateGeometry( Action action );

  //! max index
  const unsigned int& _maximumIndex( void ) const
  { return max_index_; }

  //! max index
  void _setMaximumIndex( const unsigned int& index )
  { max_index_ = index; }

  //! max index
  QSize& _maximumButtonSize( void )
  { return max_button_size_; }

  //! max index
  void _setMaximumButtonSize( const QSize& size )
  { max_button_size_ = size; }

  //! current index
  const unsigned int& _index( void ) const
  { return index_; }

  //! current index
  void _setIndex( const unsigned int& index )
  { index_ = index; }

  //! direction
  const TaskButton::Direction& _direction( void ) const
  { return direction_; }

  //! zoom direction
  void _setDirection( const TaskButton::Direction& direction )
  { direction_ = direction; }

  //! enable move
  virtual void _setEnableMove( const bool& value = true );

  //! visible rect
  virtual const QRect& _visibleRect( void ) const
  { return visible_rect_; }

  //! visible rect
  virtual QRect& _visibleRect( void )
  { return visible_rect_; }

  //! visible rect
  virtual void _setVisibleRect( const QRect& rect )
  { visible_rect_ = rect; }

  //! root pixmap
  virtual QPixmap _rootPixmap( void ) const
  { return root_pixmap_; }

  //! root pixmap
  virtual QPixmap& _rootPixmap( void )
  { return root_pixmap_; }

  //! root pixmap
  virtual void _setRootPixmap( QPixmap pixmap )
  { root_pixmap_ = pixmap; }

  //! root pixmap needs update
  virtual const bool& _rootPixmapChanged( void ) const
  { return root_pixmap_changed_; }

  //! root pixmap needs update
  virtual void _setRootPixmapChanged( const bool& value )
  { root_pixmap_changed_ = value; }

  private:

  //! get button size index
  unsigned int _index( const TaskButton::Pointer& button );

  //! get button size index
  unsigned int _index( const double& distance );

  //! preload svg
  void _preloadSvg( void ) const;

  //! taskbar minimum size
  QRect minimum_rect_;

  //! taskbar maximum size
  std::vector<QSize> maximum_sizes_;

  //! mid position (that makes the bar switch from one anchor to the other)
  std::vector<QPoint> mid_positions_;

  //! mouse offset
  QPoint mouse_offset_;

  //! max index
  unsigned int max_index_;

  //! max size
  QSize max_button_size_;

  //! current index
  unsigned int index_;

  //! zoom direction
  TaskButton::Direction direction_;

  //! taskbar visible rect
  /*! this represents the rectangle that is shaded and on top of which the buttons are drawn */
  QRect visible_rect_;

  //! root pixmap
  QPixmap root_pixmap_;

  //! root pixmap needs update
  bool root_pixmap_changed_;

};

#endif
